# Google の Ads Data Hub を Python で利用するためのライブラリ

[![pypi package](https://badge.fury.io/py/adsdatahub.svg)](https://pypi.org/project/adsdatahub)

## 使い方

[examples](https://github.com/yassun7010/adsdatahub-py/tree/main/examples) を参考にすること。
